# Changelog

All notable changes to the Azure Pricing MCP Server will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.2.0] - 2025-06-21

### 🚀 Major Optimization Release

#### Added
- **Token-optimized responses** - Dramatically reduced response sizes for better Amazon Q CLI performance
- **Smart data truncation** - Long service/SKU names limited to 50 characters
- **Concise error handling** - Error messages truncated to 100 characters
- **Performance metrics** - Added response size optimization tracking
- **Ultra-concise summary mode** - New default report format for minimal token usage

#### Changed
- **API response limits** - Reduced from 50 items to 5-10 items (80% reduction)
- **Sample SKU display** - Reduced from 3 full objects to 3 truncated objects (60% reduction)
- **Regional comparison limit** - Maximum 4 regions per comparison
- **Request timeout** - Reduced from 30s to 15s for faster failures
- **Default report format** - Changed from "markdown" to "summary"
- **Response structure** - Flattened data structure with essential information only

#### Optimized
- **get_pricing_api** - Returns price ranges and summaries instead of full item lists
- **compare_regions** - Returns statistical summaries instead of full regional data
- **get_pricing_summary** - Ultra-concise format with minimal data
- **generate_report** - Compact summary format by default

#### Performance Improvements
- **Token usage reduction** - 70-80% reduction in response tokens
- **Faster API calls** - Reduced timeout and data processing
- **Memory efficiency** - Smaller data structures and limited object creation

### Technical Details
- Response size optimization across all tools
- String truncation for long names and descriptions
- Statistical summaries instead of raw data dumps
- Error message compression for better UX

---

## [1.1.0] - 2025-06-21

### 🏢 P6P Lab Branding Release

#### Added
- **P6P Lab branding** - Complete rebrand from AWS Labs to P6P Lab
- **Updated package structure** - Changed from `awslabs` to `p6plab` namespace
- **New package name** - `p6plab.azure-pricing-mcp-server`
- **Updated documentation** - README.md with P6P Lab information
- **Environment variable documentation** - Comprehensive env var guide

#### Changed
- **Package namespace** - `awslabs.azure_pricing_mcp_server` → `p6plab.azure_pricing_mcp_server`
- **Server name** - `awslabs.azure-pricing-mcp-server` → `p6plab.azure-pricing-mcp-server`
- **Command entry point** - Updated script entry point
- **Author information** - Changed to P6P Lab in package metadata
- **Copyright notices** - Updated NOTICE file with P6P Lab copyright

#### Updated
- **All MCP configuration files** - Updated 11 JSON configuration files in `.amazonq/`
- **Installation instructions** - Updated wheel file references
- **PyPI package references** - Updated remote package names
- **README.md** - Added both local and PyPI installation examples

#### Configuration Files Updated
- `mcp.json` - Main configuration
- `mcp-working.json` - Working configuration  
- `mcp-uvx-local.json` - Local development configurations (6 variants)
- `mcp-uvx-remote.json` - Remote PyPI configurations
- `mcp-logging.json` - Logging configurations (5 variants)
- `mcp-optimized.json` - Optimized configurations
- `mcp-debug-full.json` - Full debug configuration
- `mcp-remote-test.json` - Remote test configuration
- `mcp-with-logging.json` - Protocol logging configuration

---

## [1.0.0] - 2025-06-21

### 🎉 Initial Release

#### Added
- **Core Azure Pricing Tools**
  - `get_pricing_api` - Fetch Azure pricing from Retail Prices API
  - `compare_regions` - Compare pricing across multiple Azure regions
  - `get_pricing_summary` - Get concise pricing summaries
  - `generate_report` - Create comprehensive cost analysis reports

#### Features
- **Azure Retail Prices API Integration** - Direct integration with Azure's official pricing API
- **Multi-region Support** - Compare pricing across different Azure regions
- **Currency Support** - Support for multiple currencies (USD, EUR, etc.)
- **Flexible Filtering** - Filter by service name, region, product name, SKU name
- **Report Generation** - Generate reports in markdown and CSV formats
- **Error Handling** - Comprehensive error handling and logging

#### Technical Implementation
- **FastMCP Framework** - Built on FastMCP for MCP protocol compliance
- **Async HTTP Client** - Uses httpx for efficient API calls
- **Pydantic Models** - Type-safe data validation
- **Comprehensive Logging** - Structured logging with multiple levels
- **Environment Configuration** - Configurable via environment variables

#### Environment Variables Support
- **MCP Framework Configuration**
  - `MCP_DEBUG_LOGGING` - Enable/disable debug logging
  - `MCP_LOG_LEVEL` - Set logging level (DEBUG, INFO, WARNING, ERROR)
  - `MCP_LOG_FORMAT` - Log output format (json, plain)
  - `MCP_LOG_FILE` - Log file path
  - `FASTMCP_LOG_LEVEL` - FastMCP framework log level

- **Azure Service Configuration**
  - `DEFAULT_CURRENCY` - Default currency for pricing
  - `DEFAULT_REGION` - Default Azure region
  - `AZURE_PRICING_API_BASE_URL` - Azure Retail Prices API URL

- **Performance Configuration**
  - `CACHE_TTL_SECONDS` - Cache time-to-live (prepared for future)
  - `REQUEST_TIMEOUT` - HTTP request timeout
  - `PYTHONUNBUFFERED` - Python output buffering control

#### MCP Configuration Support
- **Multiple Configuration Variants** - 11 different MCP configuration files
- **Local and Remote Installation** - Support for both wheel files and PyPI
- **Debug and Production Modes** - Optimized configurations for different use cases
- **Logging Configurations** - Various logging setups for troubleshooting

#### Documentation
- **Comprehensive README** - Installation, usage, and configuration guide
- **Environment Variables Guide** - Complete documentation of all supported env vars
- **Configuration Examples** - Multiple real-world configuration examples
- **Usage Examples** - Sample queries and expected responses

#### Package Structure
```
azure-pricing-mcp-server/
├── awslabs/                    # Package namespace (later changed to p6plab)
│   └── azure_pricing_mcp_server/
│       ├── __init__.py
│       └── server.py           # Main server implementation
├── .amazonq/                   # MCP configuration files
│   ├── mcp.json               # Main configuration
│   └── ...                    # 10 other configuration variants
├── dist/                      # Built packages
├── pyproject.toml             # Package configuration
├── README.md                  # Documentation
├── LICENSE                    # Apache 2.0 License
└── NOTICE                     # Copyright notice
```

#### Initial Capabilities
- **Service Discovery** - Automatic discovery of Azure services
- **Price Comparison** - Side-by-side regional price comparisons
- **Data Formatting** - Clean, structured pricing data output
- **Error Recovery** - Graceful handling of API failures
- **Timeout Management** - Configurable request timeouts
- **Logging Integration** - Full integration with MCP logging framework

---

## Development Notes

### Version Numbering
- **Major versions** (x.0.0) - Breaking changes, major feature additions
- **Minor versions** (x.y.0) - New features, optimizations, non-breaking changes  
- **Patch versions** (x.y.z) - Bug fixes, minor improvements

### Release Process
1. Update version numbers in `pyproject.toml` and `__init__.py` files
2. Update CHANGELOG.md with new version details
3. Build package with `uv build`
4. Update MCP configuration files with new wheel references
5. Test functionality with Amazon Q CLI
6. Tag release in version control

### Future Roadmap
- **Caching Implementation** - Add response caching for better performance
- **Advanced Filtering** - More sophisticated filtering options
- **Cost Optimization Recommendations** - AI-powered cost optimization suggestions
- **Historical Pricing** - Track pricing changes over time
- **Bulk Operations** - Support for bulk pricing queries
- **Custom Reports** - User-defined report templates
